@@ -23,8 +23,8 @@
 #ifndef KONQUEST_MAP_H
 #define KONQUEST_MAP_H
 
-#include <QObject>
 #include <QList>
+#include <QObject>
 
 #include "sector.h"
 #include "../players/player.h"
@@ -67,12 +67,12 @@ public:
         return NULL;
     }
 
-    QList<Planet*> planets();
+    const QList<Planet*> planets();
 
-protected slots:
+protected:
     void childSectorUpdate();
 
-signals:
+Q_SIGNALS:
     void update();
 
 private:
